#include<stdlib.h>
#include<stdio.h>

int mainw()
{
  system("SpectralGEM_v2.1.exe < tmp00001.txt");
  system("rm -f tmp00001.txt");
}
